// **********************************************************************
//
// Copyright (c) 2003-2016 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.6.3
//
// <auto-generated>
//
// Generated from file `RenderingEngine.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Defines a service to render a given pixels set.
 *
 * A pixels set is a <i>5D</i> array that stores the pixels data of an
 * image, that is the pixels intensity values. Every instance of this
 * service is paired up to a pixels set. Use this service to transform
 * planes within the pixels set onto an <i>RGB</i> image.
 *
 * The RenderingEngine allows to fine-tune the settings that
 * define the transformation context &#151; that is, a specification
 * of how raw pixels data is to be transformed into an image that can
 * be displayed on screen. Those settings are referred to as rendering
 * settings or display options. After tuning those settings it is
 * possible to save them to the metadata repository so that they can
 * be used the next time the pixels set is accessed for rendering; for
 * example by another RenderingEngine instance. Note that the display
 * options are specific to the given pixels set and are experimenter
 * scoped &#151; that is, two different users can specify different
 * display options for the <i>same</i> pixels set. (A RenderingEngine
 * instance takes this into account automatically as it is always
 * bound to a given experimenter.)
 *
 * This service is <b>thread-safe</b>.
 **/
public interface RenderingEnginePrx extends PyramidServicePrx
{
    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     *
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @return An <i>RGB</i> image ready to be displayed on screen.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     **/
    public omero.romio.RGBBuffer render(omero.romio.PlaneDef def)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     *
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @return An <i>RGB</i> image ready to be displayed on screen.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     **/
    public omero.romio.RGBBuffer render(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, Ice.Callback __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, Callback_RenderingEngine_render __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx, Callback_RenderingEngine_render __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, 
                                        IceInternal.Functional_GenericCallback1<omero.romio.RGBBuffer> __responseCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, 
                                        IceInternal.Functional_GenericCallback1<omero.romio.RGBBuffer> __responseCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                        IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, 
                                        java.util.Map<String, String> __ctx, 
                                        IceInternal.Functional_GenericCallback1<omero.romio.RGBBuffer> __responseCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_render(omero.romio.PlaneDef def, 
                                        java.util.Map<String, String> __ctx, 
                                        IceInternal.Functional_GenericCallback1<omero.romio.RGBBuffer> __responseCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                        IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                        IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param __result The asynchronous result object.
     * @return An <i>RGB</i> image ready to be displayed on screen.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     **/
    public omero.romio.RGBBuffer end_render(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     *
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @return An <i>RGB</i> image ready to be displayed on screen.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     * @see {@link #render}
     **/
    public int[] renderAsPackedInt(omero.romio.PlaneDef def)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     *
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @return An <i>RGB</i> image ready to be displayed on screen.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     * @see {@link #render}
     **/
    public int[] renderAsPackedInt(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, Ice.Callback __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, Callback_RenderingEngine_renderAsPackedInt __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx, Callback_RenderingEngine_renderAsPackedInt __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, 
                                                   IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, 
                                                   IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, 
                                                   java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderAsPackedInt(omero.romio.PlaneDef def, 
                                                   java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param __result The asynchronous result object.
     * @return An <i>RGB</i> image ready to be displayed on screen.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     * @see {@link #render}
     **/
    public int[] end_renderAsPackedInt(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     *
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param end Optical section to finish projecting.
     * @return A packed-integer <i>RGBA</i> rendered image of the
     * projected pixels.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * </ul>
     * @see omero.api.IProjection#projectPixels
     **/
    public int[] renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     *
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param end Optical section to finish projecting.
     * @param __ctx The Context map to send with the invocation.
     * @return A packed-integer <i>RGBA</i> rendered image of the
     * projected pixels.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * </ul>
     * @see omero.api.IProjection#projectPixels
     **/
    public int[] renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, Ice.Callback __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, Callback_RenderingEngine_renderProjectedAsPackedInt __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx, Callback_RenderingEngine_renderProjectedAsPackedInt __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, 
                                                            int timepoint, 
                                                            int stepping, 
                                                            int start, 
                                                            int end, 
                                                            IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, 
                                                            int timepoint, 
                                                            int stepping, 
                                                            int start, 
                                                            int end, 
                                                            IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                            IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, 
                                                            int timepoint, 
                                                            int stepping, 
                                                            int start, 
                                                            int end, 
                                                            java.util.Map<String, String> __ctx, 
                                                            IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedAsPackedInt(omero.constants.projection.ProjectionType algorithm, 
                                                            int timepoint, 
                                                            int stepping, 
                                                            int start, 
                                                            int end, 
                                                            java.util.Map<String, String> __ctx, 
                                                            IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                            IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param __result The asynchronous result object.
     * @return A packed-integer <i>RGBA</i> rendered image of the
     * projected pixels.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * </ul>
     * @see omero.api.IProjection#projectPixels
     **/
    public int[] end_renderProjectedAsPackedInt(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     *
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @return A compressed RGBA JPEG for display.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     * @see #render
     * @see #renderAsPackedInt
     **/
    public byte[] renderCompressed(omero.romio.PlaneDef def)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     *
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @return A compressed RGBA JPEG for display.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     * @see #render
     * @see #renderAsPackedInt
     **/
    public byte[] renderCompressed(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, Ice.Callback __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, Callback_RenderingEngine_renderCompressed __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, java.util.Map<String, String> __ctx, Callback_RenderingEngine_renderCompressed __cb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, 
                                                  IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, 
                                                  IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderCompressed(omero.romio.PlaneDef def, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param __result The asynchronous result object.
     * @return A compressed RGBA JPEG for display.
     * @throws ValidationException
     * If <code>def</code> is <code>null</code>.
     * @see #render
     * @see #renderAsPackedInt
     **/
    public byte[] end_renderCompressed(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     *
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param end Optical section to finish projecting.
     * @return A compressed <i>RGBA</i> rendered JPEG image of the
     * projected pixels.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * </ul>
     * @see omero.api.IProjection#projectPixels
     **/
    public byte[] renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     *
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param end Optical section to finish projecting.
     * @param __ctx The Context map to send with the invocation.
     * @return A compressed <i>RGBA</i> rendered JPEG image of the
     * projected pixels.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * </ul>
     * @see omero.api.IProjection#projectPixels
     **/
    public byte[] renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, Ice.Callback __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, Callback_RenderingEngine_renderProjectedCompressed __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end, java.util.Map<String, String> __ctx, Callback_RenderingEngine_renderProjectedCompressed __cb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, 
                                                           int timepoint, 
                                                           int stepping, 
                                                           int start, 
                                                           int end, 
                                                           IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, 
                                                           int timepoint, 
                                                           int stepping, 
                                                           int start, 
                                                           int end, 
                                                           IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                           IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, 
                                                           int timepoint, 
                                                           int stepping, 
                                                           int start, 
                                                           int end, 
                                                           java.util.Map<String, String> __ctx, 
                                                           IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_renderProjectedCompressed(omero.constants.projection.ProjectionType algorithm, 
                                                           int timepoint, 
                                                           int stepping, 
                                                           int start, 
                                                           int end, 
                                                           java.util.Map<String, String> __ctx, 
                                                           IceInternal.Functional_GenericCallback1<byte[]> __responseCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                           IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param __result The asynchronous result object.
     * @return A compressed <i>RGBA</i> rendered JPEG image of the
     * projected pixels.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * </ul>
     * @see omero.api.IProjection#projectPixels
     **/
    public byte[] end_renderProjectedCompressed(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     **/
    public long getRenderingDefId()
        throws omero.ServerError;

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __ctx The Context map to send with the invocation.
     **/
    public long getRenderingDefId(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId();

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(java.util.Map<String, String> __ctx);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(Ice.Callback __cb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(Callback_RenderingEngine_getRenderingDefId __cb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getRenderingDefId __cb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRenderingDefId(java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __result The asynchronous result object.
     **/
    public long end_getRenderingDefId(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Loads the Pixels set this Rendering Engine is for.
     *
     * @param pixelsId The pixels set ID.
     **/
    public void lookupPixels(long pixelsId)
        throws omero.ServerError;

    /**
     * Loads the Pixels set this Rendering Engine is for.
     *
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void lookupPixels(long pixelsId, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, java.util.Map<String, String> __ctx);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, Ice.Callback __cb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, Callback_RenderingEngine_lookupPixels __cb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, java.util.Map<String, String> __ctx, Callback_RenderingEngine_lookupPixels __cb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, 
                                              IceInternal.Functional_VoidCallback __responseCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, 
                                              IceInternal.Functional_VoidCallback __responseCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                              IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, 
                                              java.util.Map<String, String> __ctx, 
                                              IceInternal.Functional_VoidCallback __responseCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupPixels(long pixelsId, 
                                              java.util.Map<String, String> __ctx, 
                                              IceInternal.Functional_VoidCallback __responseCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                              IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_lookupPixels(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     *
     * @param pixelsId The pixels set ID.
     * @return <code>true</code> if a RenderingDef exists for the
     * Pixels set, otherwise <code>false</code>.
     **/
    public boolean lookupRenderingDef(long pixelsId)
        throws omero.ServerError;

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     *
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @return <code>true</code> if a RenderingDef exists for the
     * Pixels set, otherwise <code>false</code>.
     **/
    public boolean lookupRenderingDef(long pixelsId, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, java.util.Map<String, String> __ctx);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, Ice.Callback __cb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, Callback_RenderingEngine_lookupRenderingDef __cb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, java.util.Map<String, String> __ctx, Callback_RenderingEngine_lookupRenderingDef __cb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, 
                                                    IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, 
                                                    IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, 
                                                    java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param pixelsId The pixels set ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_lookupRenderingDef(long pixelsId, 
                                                    java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param __result The asynchronous result object.
     * @return <code>true</code> if a RenderingDef exists for the
     * Pixels set, otherwise <code>false</code>.
     **/
    public boolean end_lookupRenderingDef(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     *
     * @param renderingDefId The rendering definition ID.
     * @throws ValidationException If a RenderingDef does not
     * exist with the ID <code>renderingDefId</code> or if
     * the RenderingDef is incompatible due to differing
     * pixels sets.
     **/
    public void loadRenderingDef(long renderingDefId)
        throws omero.ServerError;

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     *
     * @param renderingDefId The rendering definition ID.
     * @throws ValidationException If a RenderingDef does not
     * exist with the ID <code>renderingDefId</code> or if
     * the RenderingDef is incompatible due to differing
     * pixels sets.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void loadRenderingDef(long renderingDefId, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, java.util.Map<String, String> __ctx);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, Ice.Callback __cb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, Callback_RenderingEngine_loadRenderingDef __cb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, java.util.Map<String, String> __ctx, Callback_RenderingEngine_loadRenderingDef __cb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param renderingDefId The rendering definition ID.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_loadRenderingDef(long renderingDefId, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param __result The asynchronous result object.
     * @throws ValidationException If a RenderingDef does not
     * exist with the ID <code>renderingDefId</code> or if
     * the RenderingDef is incompatible due to differing
     * pixels sets.
     **/
    public void end_loadRenderingDef(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param overlays Binary mask to color map.
     * @deprecated This operation has been deprecated.
     **/
    public void setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap)
        throws omero.ServerError;

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param overlays Binary mask to color map.
     * @param __ctx The Context map to send with the invocation.
     * @deprecated This operation has been deprecated.
     **/
    public void setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, java.util.Map<String, String> __ctx);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, Ice.Callback __cb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, Callback_RenderingEngine_setOverlays __cb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setOverlays __cb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, 
                                             omero.RLong imageId, 
                                             java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, 
                                             omero.RLong imageId, 
                                             java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, 
                                             omero.RLong imageId, 
                                             java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, 
                                             java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_setOverlays(omero.RLong tablesId, 
                                             omero.RLong imageId, 
                                             java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap, 
                                             java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __result The asynchronous result object.
     **/
    public void end_setOverlays(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Creates an instance of the rendering engine.
     **/
    public void load()
        throws omero.ServerError;

    /**
     * Creates an instance of the rendering engine.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void load(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Creates an instance of the rendering engine.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load();

    /**
     * Creates an instance of the rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(java.util.Map<String, String> __ctx);

    /**
     * Creates an instance of the rendering engine.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(Ice.Callback __cb);

    /**
     * Creates an instance of the rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Creates an instance of the rendering engine.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(Callback_RenderingEngine_load __cb);

    /**
     * Creates an instance of the rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(java.util.Map<String, String> __ctx, Callback_RenderingEngine_load __cb);

    /**
     * Creates an instance of the rendering engine.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(IceInternal.Functional_VoidCallback __responseCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Creates an instance of the rendering engine.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(IceInternal.Functional_VoidCallback __responseCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                      IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Creates an instance of the rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(java.util.Map<String, String> __ctx, 
                                      IceInternal.Functional_VoidCallback __responseCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Creates an instance of the rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_load(java.util.Map<String, String> __ctx, 
                                      IceInternal.Functional_VoidCallback __responseCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                      IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Creates an instance of the rendering engine.
     * @param __result The asynchronous result object.
     **/
    public void end_load(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     *
     * @param model Identifies the color space model.
     **/
    public void setModel(omero.model.RenderingModel model)
        throws omero.ServerError;

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     *
     * @param model Identifies the color space model.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setModel(omero.model.RenderingModel model, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, java.util.Map<String, String> __ctx);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, Ice.Callback __cb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, Callback_RenderingEngine_setModel __cb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setModel __cb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, 
                                          IceInternal.Functional_VoidCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, 
                                          IceInternal.Functional_VoidCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, 
                                          java.util.Map<String, String> __ctx, 
                                          IceInternal.Functional_VoidCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param model Identifies the color space model.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setModel(omero.model.RenderingModel model, 
                                          java.util.Map<String, String> __ctx, 
                                          IceInternal.Functional_VoidCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setModel(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     **/
    public omero.model.RenderingModel getModel()
        throws omero.ServerError;

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.model.RenderingModel getModel(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel();

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(java.util.Map<String, String> __ctx);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(Ice.Callback __cb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(Callback_RenderingEngine_getModel __cb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getModel __cb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(IceInternal.Functional_GenericCallback1<omero.model.RenderingModel> __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(IceInternal.Functional_GenericCallback1<omero.model.RenderingModel> __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(java.util.Map<String, String> __ctx, 
                                          IceInternal.Functional_GenericCallback1<omero.model.RenderingModel> __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getModel(java.util.Map<String, String> __ctx, 
                                          IceInternal.Functional_GenericCallback1<omero.model.RenderingModel> __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __result The asynchronous result object.
     **/
    public omero.model.RenderingModel end_getModel(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the index of the default focal section.
     **/
    public int getDefaultZ()
        throws omero.ServerError;

    /**
     * Returns the index of the default focal section.
     * @param __ctx The Context map to send with the invocation.
     **/
    public int getDefaultZ(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the index of the default focal section.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ();

    /**
     * Returns the index of the default focal section.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(java.util.Map<String, String> __ctx);

    /**
     * Returns the index of the default focal section.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(Ice.Callback __cb);

    /**
     * Returns the index of the default focal section.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the index of the default focal section.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(Callback_RenderingEngine_getDefaultZ __cb);

    /**
     * Returns the index of the default focal section.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getDefaultZ __cb);

    /**
     * Returns the index of the default focal section.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the index of the default focal section.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the index of the default focal section.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the index of the default focal section.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultZ(java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the index of the default focal section.
     * @param __result The asynchronous result object.
     **/
    public int end_getDefaultZ(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the default timepoint index.
     **/
    public int getDefaultT()
        throws omero.ServerError;

    /**
     * Returns the default timepoint index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public int getDefaultT(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the default timepoint index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT();

    /**
     * Returns the default timepoint index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(java.util.Map<String, String> __ctx);

    /**
     * Returns the default timepoint index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(Ice.Callback __cb);

    /**
     * Returns the default timepoint index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the default timepoint index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(Callback_RenderingEngine_getDefaultT __cb);

    /**
     * Returns the default timepoint index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getDefaultT __cb);

    /**
     * Returns the default timepoint index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the default timepoint index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the default timepoint index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the default timepoint index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getDefaultT(java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_IntCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the default timepoint index.
     * @param __result The asynchronous result object.
     **/
    public int end_getDefaultT(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     *
     * @param z The value to set.
     **/
    public void setDefaultZ(int z)
        throws omero.ServerError;

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     *
     * @param z The value to set.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setDefaultZ(int z, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, java.util.Map<String, String> __ctx);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, Ice.Callback __cb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, Callback_RenderingEngine_setDefaultZ __cb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setDefaultZ __cb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, 
                                             java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param z The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultZ(int z, 
                                             java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setDefaultZ(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     *
     * @param t The value to set.
     **/
    public void setDefaultT(int t)
        throws omero.ServerError;

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     *
     * @param t The value to set.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setDefaultT(int t, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, java.util.Map<String, String> __ctx);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, Ice.Callback __cb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, Callback_RenderingEngine_setDefaultT __cb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setDefaultT __cb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, 
                                             java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param t The value to set.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setDefaultT(int t, 
                                             java.util.Map<String, String> __ctx, 
                                             IceInternal.Functional_VoidCallback __responseCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                             IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                             IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setDefaultT(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     **/
    public omero.model.Pixels getPixels()
        throws omero.ServerError;

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.model.Pixels getPixels(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels();

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(java.util.Map<String, String> __ctx);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(Ice.Callback __cb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(Callback_RenderingEngine_getPixels __cb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getPixels __cb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(IceInternal.Functional_GenericCallback1<omero.model.Pixels> __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(IceInternal.Functional_GenericCallback1<omero.model.Pixels> __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                           IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(java.util.Map<String, String> __ctx, 
                                           IceInternal.Functional_GenericCallback1<omero.model.Pixels> __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixels(java.util.Map<String, String> __ctx, 
                                           IceInternal.Functional_GenericCallback1<omero.model.Pixels> __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                           IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __result The asynchronous result object.
     **/
    public omero.model.Pixels end_getPixels(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     **/
    public java.util.List<omero.model.IObject> getAvailableModels()
        throws omero.ServerError;

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.IObject> getAvailableModels(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels();

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(java.util.Map<String, String> __ctx);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(Ice.Callback __cb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(Callback_RenderingEngine_getAvailableModels __cb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getAvailableModels __cb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableModels(java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __result The asynchronous result object.
     **/
    public java.util.List<omero.model.IObject> end_getAvailableModels(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     **/
    public java.util.List<omero.model.IObject> getAvailableFamilies()
        throws omero.ServerError;

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.IObject> getAvailableFamilies(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies();

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(java.util.Map<String, String> __ctx);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(Ice.Callback __cb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(Callback_RenderingEngine_getAvailableFamilies __cb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getAvailableFamilies __cb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                      IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(java.util.Map<String, String> __ctx, 
                                                      IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getAvailableFamilies(java.util.Map<String, String> __ctx, 
                                                      IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                      IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __result The asynchronous result object.
     **/
    public java.util.List<omero.model.IObject> end_getAvailableFamilies(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     *
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     **/
    public void setQuantumStrategy(int bitResolution)
        throws omero.ServerError;

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     *
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setQuantumStrategy(int bitResolution, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, java.util.Map<String, String> __ctx);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, Ice.Callback __cb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, Callback_RenderingEngine_setQuantumStrategy __cb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setQuantumStrategy __cb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, 
                                                    java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantumStrategy(int bitResolution, 
                                                    java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setQuantumStrategy(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     *
     * @param start The lower bound of the interval.
     * @param end The upper bound of the interval.
     **/
    public void setCodomainInterval(int start, int end)
        throws omero.ServerError;

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     *
     * @param start The lower bound of the interval.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setCodomainInterval(int start, int end, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, int end);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, int end, java.util.Map<String, String> __ctx);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, int end, Ice.Callback __cb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, int end, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, int end, Callback_RenderingEngine_setCodomainInterval __cb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, int end, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setCodomainInterval __cb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, 
                                                     int end, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, 
                                                     int end, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, 
                                                     int end, 
                                                     java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param start The lower bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCodomainInterval(int start, 
                                                     int end, 
                                                     java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setCodomainInterval(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the quantization object.
     **/
    public omero.model.QuantumDef getQuantumDef()
        throws omero.ServerError;

    /**
     * Returns the quantization object.
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.model.QuantumDef getQuantumDef(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the quantization object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef();

    /**
     * Returns the quantization object.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(java.util.Map<String, String> __ctx);

    /**
     * Returns the quantization object.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(Ice.Callback __cb);

    /**
     * Returns the quantization object.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the quantization object.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(Callback_RenderingEngine_getQuantumDef __cb);

    /**
     * Returns the quantization object.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getQuantumDef __cb);

    /**
     * Returns the quantization object.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(IceInternal.Functional_GenericCallback1<omero.model.QuantumDef> __responseCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the quantization object.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(IceInternal.Functional_GenericCallback1<omero.model.QuantumDef> __responseCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                               IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the quantization object.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(java.util.Map<String, String> __ctx, 
                                               IceInternal.Functional_GenericCallback1<omero.model.QuantumDef> __responseCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the quantization object.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getQuantumDef(java.util.Map<String, String> __ctx, 
                                               IceInternal.Functional_GenericCallback1<omero.model.QuantumDef> __responseCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                               IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                               IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the quantization object.
     * @param __result The asynchronous result object.
     **/
    public omero.model.QuantumDef end_getQuantumDef(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the quantization map, one per channel.
     *
     * @param w  The channel index.
     * @param family The mapping family.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @see #getAvailableFamilies
     * @see #getChannelCurveCoefficient
     * @see #getChannelFamily
     * @see #getChannelNoiseReduction
     **/
    public void setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction)
        throws omero.ServerError;

    /**
     * Sets the quantization map, one per channel.
     *
     * @param w  The channel index.
     * @param family The mapping family.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @see #getAvailableFamilies
     * @see #getChannelCurveCoefficient
     * @see #getChannelFamily
     * @see #getChannelNoiseReduction
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction, java.util.Map<String, String> __ctx);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction, Ice.Callback __cb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction, Callback_RenderingEngine_setQuantizationMap __cb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, omero.model.Family fam, double coefficient, boolean noiseReduction, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setQuantizationMap __cb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, 
                                                    omero.model.Family fam, 
                                                    double coefficient, 
                                                    boolean noiseReduction, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, 
                                                    omero.model.Family fam, 
                                                    double coefficient, 
                                                    boolean noiseReduction, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, 
                                                    omero.model.Family fam, 
                                                    double coefficient, 
                                                    boolean noiseReduction, 
                                                    java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setQuantizationMap(int w, 
                                                    omero.model.Family fam, 
                                                    double coefficient, 
                                                    boolean noiseReduction, 
                                                    java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_VoidCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param __result The asynchronous result object.
     * @see #getAvailableFamilies
     * @see #getChannelCurveCoefficient
     * @see #getChannelFamily
     * @see #getChannelNoiseReduction
     **/
    public void end_setQuantizationMap(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the family associated to the specified channel.
     *
     * @param w The channel index.
     * @return See above.
     * @see #getAvailableFamilies
     **/
    public omero.model.Family getChannelFamily(int w)
        throws omero.ServerError;

    /**
     * Returns the family associated to the specified channel.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return See above.
     * @see #getAvailableFamilies
     **/
    public omero.model.Family getChannelFamily(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, Ice.Callback __cb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, Callback_RenderingEngine_getChannelFamily __cb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelFamily __cb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, 
                                                  IceInternal.Functional_GenericCallback1<omero.model.Family> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, 
                                                  IceInternal.Functional_GenericCallback1<omero.model.Family> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_GenericCallback1<omero.model.Family> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelFamily(int w, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_GenericCallback1<omero.model.Family> __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param __result The asynchronous result object.
     * @return See above.
     * @see #getAvailableFamilies
     **/
    public omero.model.Family end_getChannelFamily(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     *
     * @param w The channel index.
     * @return See above.
     **/
    public boolean getChannelNoiseReduction(int w)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return See above.
     **/
    public boolean getChannelNoiseReduction(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, Ice.Callback __cb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, Callback_RenderingEngine_getChannelNoiseReduction __cb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelNoiseReduction __cb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, 
                                                          IceInternal.Functional_BoolCallback __responseCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, 
                                                          IceInternal.Functional_BoolCallback __responseCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, 
                                                          java.util.Map<String, String> __ctx, 
                                                          IceInternal.Functional_BoolCallback __responseCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelNoiseReduction(int w, 
                                                          java.util.Map<String, String> __ctx, 
                                                          IceInternal.Functional_BoolCallback __responseCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param __result The asynchronous result object.
     * @return See above.
     **/
    public boolean end_getChannelNoiseReduction(Ice.AsyncResult __result)
        throws omero.ServerError;

    public double[] getChannelStats(int w)
        throws omero.ServerError;

    public double[] getChannelStats(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    public Ice.AsyncResult begin_getChannelStats(int w);

    public Ice.AsyncResult begin_getChannelStats(int w, java.util.Map<String, String> __ctx);

    public Ice.AsyncResult begin_getChannelStats(int w, Ice.Callback __cb);

    public Ice.AsyncResult begin_getChannelStats(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    public Ice.AsyncResult begin_getChannelStats(int w, Callback_RenderingEngine_getChannelStats __cb);

    public Ice.AsyncResult begin_getChannelStats(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelStats __cb);

    public Ice.AsyncResult begin_getChannelStats(int w, 
                                                 IceInternal.Functional_GenericCallback1<double[]> __responseCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    public Ice.AsyncResult begin_getChannelStats(int w, 
                                                 IceInternal.Functional_GenericCallback1<double[]> __responseCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                 IceInternal.Functional_BoolCallback __sentCb);

    public Ice.AsyncResult begin_getChannelStats(int w, 
                                                 java.util.Map<String, String> __ctx, 
                                                 IceInternal.Functional_GenericCallback1<double[]> __responseCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    public Ice.AsyncResult begin_getChannelStats(int w, 
                                                 java.util.Map<String, String> __ctx, 
                                                 IceInternal.Functional_GenericCallback1<double[]> __responseCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                 IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                 IceInternal.Functional_BoolCallback __sentCb);

    public double[] end_getChannelStats(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     *
     * @param w The channel index.
     * @return See above.
     * @see #getChannelFamily
     **/
    public double getChannelCurveCoefficient(int w)
        throws omero.ServerError;

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return See above.
     * @see #getChannelFamily
     **/
    public double getChannelCurveCoefficient(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, Ice.Callback __cb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, Callback_RenderingEngine_getChannelCurveCoefficient __cb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelCurveCoefficient __cb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, 
                                                            IceInternal.Functional_DoubleCallback __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, 
                                                            IceInternal.Functional_DoubleCallback __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                            IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, 
                                                            java.util.Map<String, String> __ctx, 
                                                            IceInternal.Functional_DoubleCallback __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelCurveCoefficient(int w, 
                                                            java.util.Map<String, String> __ctx, 
                                                            IceInternal.Functional_DoubleCallback __responseCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                            IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                            IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param __result The asynchronous result object.
     * @return See above.
     * @see #getChannelFamily
     **/
    public double end_getChannelCurveCoefficient(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     *
     * @param w The channel index.
     * @param start The lower bound of the interval.
     * @param end The upper bound of the interval.
     **/
    public void setChannelWindow(int w, double start, double end)
        throws omero.ServerError;

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     *
     * @param w The channel index.
     * @param start The lower bound of the interval.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setChannelWindow(int w, double start, double end, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, double start, double end);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, double start, double end, java.util.Map<String, String> __ctx);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, double start, double end, Ice.Callback __cb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, double start, double end, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, double start, double end, Callback_RenderingEngine_setChannelWindow __cb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, double start, double end, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setChannelWindow __cb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, 
                                                  double start, 
                                                  double end, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, 
                                                  double start, 
                                                  double end, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, 
                                                  double start, 
                                                  double end, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param w The channel index.
     * @param end The upper bound of the interval.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setChannelWindow(int w, 
                                                  double start, 
                                                  double end, 
                                                  java.util.Map<String, String> __ctx, 
                                                  IceInternal.Functional_VoidCallback __responseCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                  IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                  IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setChannelWindow(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     *
     * @param w The channel index.
     **/
    public double getChannelWindowStart(int w)
        throws omero.ServerError;

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public double getChannelWindowStart(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, Ice.Callback __cb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, Callback_RenderingEngine_getChannelWindowStart __cb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelWindowStart __cb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, 
                                                       IceInternal.Functional_DoubleCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, 
                                                       IceInternal.Functional_DoubleCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_DoubleCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowStart(int w, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_DoubleCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param __result The asynchronous result object.
     **/
    public double end_getChannelWindowStart(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     *
     * @param w The channel index.
     **/
    public double getChannelWindowEnd(int w)
        throws omero.ServerError;

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public double getChannelWindowEnd(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, Ice.Callback __cb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, Callback_RenderingEngine_getChannelWindowEnd __cb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelWindowEnd __cb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, 
                                                     IceInternal.Functional_DoubleCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, 
                                                     IceInternal.Functional_DoubleCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, 
                                                     java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_DoubleCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getChannelWindowEnd(int w, 
                                                     java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_DoubleCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param __result The asynchronous result object.
     **/
    public double end_getChannelWindowEnd(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     *
     * @param w The channel index.
     * @param red The red component. A value between 0 and 255.
     * @param green The green component. A value between 0 and 255.
     * @param blue The blue component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     **/
    public void setRGBA(int w, int red, int green, int blue, int alpha)
        throws omero.ServerError;

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     *
     * @param w The channel index.
     * @param red The red component. A value between 0 and 255.
     * @param green The green component. A value between 0 and 255.
     * @param blue The blue component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setRGBA(int w, int red, int green, int blue, int alpha, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, int red, int green, int blue, int alpha);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, int red, int green, int blue, int alpha, java.util.Map<String, String> __ctx);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, int red, int green, int blue, int alpha, Ice.Callback __cb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, int red, int green, int blue, int alpha, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, int red, int green, int blue, int alpha, Callback_RenderingEngine_setRGBA __cb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, int red, int green, int blue, int alpha, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setRGBA __cb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, 
                                         int red, 
                                         int green, 
                                         int blue, 
                                         int alpha, 
                                         IceInternal.Functional_VoidCallback __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, 
                                         int red, 
                                         int green, 
                                         int blue, 
                                         int alpha, 
                                         IceInternal.Functional_VoidCallback __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, 
                                         int red, 
                                         int green, 
                                         int blue, 
                                         int alpha, 
                                         java.util.Map<String, String> __ctx, 
                                         IceInternal.Functional_VoidCallback __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setRGBA(int w, 
                                         int red, 
                                         int green, 
                                         int blue, 
                                         int alpha, 
                                         java.util.Map<String, String> __ctx, 
                                         IceInternal.Functional_VoidCallback __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setRGBA(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     *
     * @param w The channel index.
     **/
    public int[] getRGBA(int w)
        throws omero.ServerError;

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public int[] getRGBA(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, Ice.Callback __cb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, Callback_RenderingEngine_getRGBA __cb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getRGBA __cb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, 
                                         IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, 
                                         IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, 
                                         java.util.Map<String, String> __ctx, 
                                         IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getRGBA(int w, 
                                         java.util.Map<String, String> __ctx, 
                                         IceInternal.Functional_GenericCallback1<int[]> __responseCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param __result The asynchronous result object.
     **/
    public int[] end_getRGBA(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     *
     * @param w The channel index.
     * @param active Pass <code>true</code> to map the channel,
     * <code>false</code> otherwise.
     **/
    public void setActive(int w, boolean active)
        throws omero.ServerError;

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     *
     * @param w The channel index.
     * @param active Pass <code>true</code> to map the channel,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setActive(int w, boolean active, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, boolean active);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, boolean active, java.util.Map<String, String> __ctx);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, boolean active, Ice.Callback __cb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, boolean active, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, boolean active, Callback_RenderingEngine_setActive __cb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, boolean active, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setActive __cb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, 
                                           boolean active, 
                                           IceInternal.Functional_VoidCallback __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, 
                                           boolean active, 
                                           IceInternal.Functional_VoidCallback __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                           IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, 
                                           boolean active, 
                                           java.util.Map<String, String> __ctx, 
                                           IceInternal.Functional_VoidCallback __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setActive(int w, 
                                           boolean active, 
                                           java.util.Map<String, String> __ctx, 
                                           IceInternal.Functional_VoidCallback __responseCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                           IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                           IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param __result The asynchronous result object.
     **/
    public void end_setActive(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     *
     * @param w The channel index.
     **/
    public boolean isActive(int w)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean isActive(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, Ice.Callback __cb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, Callback_RenderingEngine_isActive __cb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_isActive __cb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, 
                                          IceInternal.Functional_BoolCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, 
                                          IceInternal.Functional_BoolCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, 
                                          java.util.Map<String, String> __ctx, 
                                          IceInternal.Functional_BoolCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isActive(int w, 
                                          java.util.Map<String, String> __ctx, 
                                          IceInternal.Functional_BoolCallback __responseCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                          IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                          IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param __result The asynchronous result object.
     **/
    public boolean end_isActive(Ice.AsyncResult __result)
        throws omero.ServerError;

    public void setChannelLookupTable(int w, String lookup)
        throws omero.ServerError;

    public void setChannelLookupTable(int w, String lookup, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    public Ice.AsyncResult begin_setChannelLookupTable(int w, String lookup);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, String lookup, java.util.Map<String, String> __ctx);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, String lookup, Ice.Callback __cb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, String lookup, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, String lookup, Callback_RenderingEngine_setChannelLookupTable __cb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, String lookup, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setChannelLookupTable __cb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, 
                                                       String lookup, 
                                                       IceInternal.Functional_VoidCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, 
                                                       String lookup, 
                                                       IceInternal.Functional_VoidCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, 
                                                       String lookup, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_VoidCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    public Ice.AsyncResult begin_setChannelLookupTable(int w, 
                                                       String lookup, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_VoidCallback __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    public void end_setChannelLookupTable(Ice.AsyncResult __result)
        throws omero.ServerError;

    public String getChannelLookupTable(int w)
        throws omero.ServerError;

    public String getChannelLookupTable(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    public Ice.AsyncResult begin_getChannelLookupTable(int w);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, java.util.Map<String, String> __ctx);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, Ice.Callback __cb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, Callback_RenderingEngine_getChannelLookupTable __cb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getChannelLookupTable __cb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, 
                                                       IceInternal.Functional_GenericCallback1<String> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, 
                                                       IceInternal.Functional_GenericCallback1<String> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_GenericCallback1<String> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    public Ice.AsyncResult begin_getChannelLookupTable(int w, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_GenericCallback1<String> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    public String end_getChannelLookupTable(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     *
     * @param mapCtx The context to add.
     * @see #updateCodomainMap
     * @see #removeCodomainMap
     * @deprecated This operation has been deprecated.
     **/
    public void addCodomainMap(omero.romio.CodomainMapContext mapCtx)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     *
     * @param mapCtx The context to add.
     * @see #updateCodomainMap
     * @see #removeCodomainMap
     * @param __ctx The Context map to send with the invocation.
     * @deprecated This operation has been deprecated.
     **/
    public void addCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, Ice.Callback __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, Callback_RenderingEngine_addCodomainMap __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx, Callback_RenderingEngine_addCodomainMap __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                IceInternal.Functional_VoidCallback __responseCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                IceInternal.Functional_VoidCallback __responseCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                java.util.Map<String, String> __ctx, 
                                                IceInternal.Functional_VoidCallback __responseCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_addCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                java.util.Map<String, String> __ctx, 
                                                IceInternal.Functional_VoidCallback __responseCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param __result The asynchronous result object.
     * @see #updateCodomainMap
     * @see #removeCodomainMap
     **/
    public void end_addCodomainMap(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     *
     * @param mapCtx The context to update.
     * @see #addCodomainMap
     * @see #removeCodomainMap
     * @deprecated This operation has been deprecated.
     **/
    public void updateCodomainMap(omero.romio.CodomainMapContext mapCtx)
        throws omero.ServerError;

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     *
     * @param mapCtx The context to update.
     * @see #addCodomainMap
     * @see #removeCodomainMap
     * @param __ctx The Context map to send with the invocation.
     * @deprecated This operation has been deprecated.
     **/
    public void updateCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, Ice.Callback __cb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, Callback_RenderingEngine_updateCodomainMap __cb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx, Callback_RenderingEngine_updateCodomainMap __cb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to update.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_updateCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param __result The asynchronous result object.
     * @see #addCodomainMap
     * @see #removeCodomainMap
     **/
    public void end_updateCodomainMap(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     *
     * @param mapCtx The context to remove.
     * @see #addCodomainMap
     * @see #updateCodomainMap
     * @deprecated This operation has been deprecated.
     **/
    public void removeCodomainMap(omero.romio.CodomainMapContext mapCtx)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     *
     * @param mapCtx The context to remove.
     * @see #addCodomainMap
     * @see #updateCodomainMap
     * @param __ctx The Context map to send with the invocation.
     * @deprecated This operation has been deprecated.
     **/
    public void removeCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, Ice.Callback __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, Callback_RenderingEngine_removeCodomainMap __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, java.util.Map<String, String> __ctx, Callback_RenderingEngine_removeCodomainMap __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     * @deprecated This operation has been deprecated.
     **/
    public Ice.AsyncResult begin_removeCodomainMap(omero.romio.CodomainMapContext mapCtx, 
                                                   java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_VoidCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param __result The asynchronous result object.
     * @see #addCodomainMap
     * @see #updateCodomainMap
     **/
    public void end_removeCodomainMap(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     *
     * @param mapCtx The context to add.
     * @param w The channel to add the context to.
     * @see #removeCodomainMapFromChannel
     **/
    public void addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     *
     * @param mapCtx The context to add.
     * @param w The channel to add the context to.
     * @see #removeCodomainMapFromChannel
     * @param __ctx The Context map to send with the invocation.
     **/
    public void addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w, Ice.Callback __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w, Callback_RenderingEngine_addCodomainMapToChannel __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_addCodomainMapToChannel __cb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, 
                                                         int w, 
                                                         IceInternal.Functional_VoidCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, 
                                                         int w, 
                                                         IceInternal.Functional_VoidCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, 
                                                         int w, 
                                                         java.util.Map<String, String> __ctx, 
                                                         IceInternal.Functional_VoidCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param mapCtx The context to add.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_addCodomainMapToChannel(omero.romio.CodomainMapContext mapCtx, 
                                                         int w, 
                                                         java.util.Map<String, String> __ctx, 
                                                         IceInternal.Functional_VoidCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param __result The asynchronous result object.
     * @see #removeCodomainMapFromChannel
     **/
    public void end_addCodomainMapToChannel(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     *
     * @param mapCtx The context to remove.
     * @param w The channel to remove the context from.
     * @see #addCodomainMapToChannel
     **/
    public void removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     *
     * @param mapCtx The context to remove.
     * @param w The channel to remove the context from.
     * @see #addCodomainMapToChannel
     * @param __ctx The Context map to send with the invocation.
     **/
    public void removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w, Ice.Callback __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w, Callback_RenderingEngine_removeCodomainMapFromChannel __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_removeCodomainMapFromChannel __cb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, 
                                                              int w, 
                                                              IceInternal.Functional_VoidCallback __responseCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, 
                                                              int w, 
                                                              IceInternal.Functional_VoidCallback __responseCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                              IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, 
                                                              int w, 
                                                              java.util.Map<String, String> __ctx, 
                                                              IceInternal.Functional_VoidCallback __responseCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param mapCtx The context to remove.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_removeCodomainMapFromChannel(omero.romio.CodomainMapContext mapCtx, 
                                                              int w, 
                                                              java.util.Map<String, String> __ctx, 
                                                              IceInternal.Functional_VoidCallback __responseCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                              IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                              IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param __result The asynchronous result object.
     * @see #addCodomainMapToChannel
     **/
    public void end_removeCodomainMapFromChannel(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database.
     **/
    public void saveCurrentSettings()
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void saveCurrentSettings(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings();

    /**
     * Saves the current rendering settings in the database.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(java.util.Map<String, String> __ctx);

    /**
     * Saves the current rendering settings in the database.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(Ice.Callback __cb);

    /**
     * Saves the current rendering settings in the database.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Saves the current rendering settings in the database.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(Callback_RenderingEngine_saveCurrentSettings __cb);

    /**
     * Saves the current rendering settings in the database.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(java.util.Map<String, String> __ctx, Callback_RenderingEngine_saveCurrentSettings __cb);

    /**
     * Saves the current rendering settings in the database.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Saves the current rendering settings in the database.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Saves the current rendering settings in the database.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Saves the current rendering settings in the database.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveCurrentSettings(java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Saves the current rendering settings in the database.
     * @param __result The asynchronous result object.
     **/
    public void end_saveCurrentSettings(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     **/
    public long saveAsNewSettings()
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __ctx The Context map to send with the invocation.
     **/
    public long saveAsNewSettings(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings();

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(java.util.Map<String, String> __ctx);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(Ice.Callback __cb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(Callback_RenderingEngine_saveAsNewSettings __cb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(java.util.Map<String, String> __ctx, Callback_RenderingEngine_saveAsNewSettings __cb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_saveAsNewSettings(java.util.Map<String, String> __ctx, 
                                                   IceInternal.Functional_LongCallback __responseCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                   IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                   IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __result The asynchronous result object.
     **/
    public long end_saveAsNewSettings(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     *
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     **/
    public long resetDefaultSettings(boolean save)
        throws omero.ServerError;

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     *
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     **/
    public long resetDefaultSettings(boolean save, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, java.util.Map<String, String> __ctx);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, Ice.Callback __cb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, Callback_RenderingEngine_resetDefaultSettings __cb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, java.util.Map<String, String> __ctx, Callback_RenderingEngine_resetDefaultSettings __cb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, 
                                                      IceInternal.Functional_LongCallback __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, 
                                                      IceInternal.Functional_LongCallback __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                      IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, 
                                                      java.util.Map<String, String> __ctx, 
                                                      IceInternal.Functional_LongCallback __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_resetDefaultSettings(boolean save, 
                                                      java.util.Map<String, String> __ctx, 
                                                      IceInternal.Functional_LongCallback __responseCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                      IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                      IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param __result The asynchronous result object.
     **/
    public long end_resetDefaultSettings(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     *
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @throws ValidationException if the <code>percentage</code
     * is out of range.
     **/
    public void setCompressionLevel(float percentage)
        throws omero.ServerError;

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     *
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @throws ValidationException if the <code>percentage</code
     * is out of range.
     * @param __ctx The Context map to send with the invocation.
     **/
    public void setCompressionLevel(float percentage, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, java.util.Map<String, String> __ctx);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, Ice.Callback __cb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, Callback_RenderingEngine_setCompressionLevel __cb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, java.util.Map<String, String> __ctx, Callback_RenderingEngine_setCompressionLevel __cb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, 
                                                     java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_setCompressionLevel(float percentage, 
                                                     java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_VoidCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param __result The asynchronous result object.
     * @throws ValidationException if the <code>percentage</code
     * is out of range.
     **/
    public void end_setCompressionLevel(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the current compression level for the service.
     **/
    public float getCompressionLevel()
        throws omero.ServerError;

    /**
     * Returns the current compression level for the service.
     * @param __ctx The Context map to send with the invocation.
     **/
    public float getCompressionLevel(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the current compression level for the service.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel();

    /**
     * Returns the current compression level for the service.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(java.util.Map<String, String> __ctx);

    /**
     * Returns the current compression level for the service.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(Ice.Callback __cb);

    /**
     * Returns the current compression level for the service.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the current compression level for the service.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(Callback_RenderingEngine_getCompressionLevel __cb);

    /**
     * Returns the current compression level for the service.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(java.util.Map<String, String> __ctx, Callback_RenderingEngine_getCompressionLevel __cb);

    /**
     * Returns the current compression level for the service.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(IceInternal.Functional_FloatCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the current compression level for the service.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(IceInternal.Functional_FloatCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the current compression level for the service.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_FloatCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the current compression level for the service.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCompressionLevel(java.util.Map<String, String> __ctx, 
                                                     IceInternal.Functional_FloatCallback __responseCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                     IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                     IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the current compression level for the service.
     * @param __result The asynchronous result object.
     **/
    public float end_getCompressionLevel(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     **/
    public boolean isPixelsTypeSigned()
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean isPixelsTypeSigned(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned();

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(java.util.Map<String, String> __ctx);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(Ice.Callback __cb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(Callback_RenderingEngine_isPixelsTypeSigned __cb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(java.util.Map<String, String> __ctx, Callback_RenderingEngine_isPixelsTypeSigned __cb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_isPixelsTypeSigned(java.util.Map<String, String> __ctx, 
                                                    IceInternal.Functional_BoolCallback __responseCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                    IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                    IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __result The asynchronous result object.
     **/
    public boolean end_isPixelsTypeSigned(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     *
     * @param w The channel index.
     **/
    public double getPixelsTypeUpperBound(int w)
        throws omero.ServerError;

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public double getPixelsTypeUpperBound(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, Ice.Callback __cb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, Callback_RenderingEngine_getPixelsTypeUpperBound __cb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getPixelsTypeUpperBound __cb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, 
                                                         java.util.Map<String, String> __ctx, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeUpperBound(int w, 
                                                         java.util.Map<String, String> __ctx, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param __result The asynchronous result object.
     **/
    public double end_getPixelsTypeUpperBound(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     *
     * @param w The channel index.
     **/
    public double getPixelsTypeLowerBound(int w)
        throws omero.ServerError;

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public double getPixelsTypeLowerBound(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, Ice.Callback __cb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, Callback_RenderingEngine_getPixelsTypeLowerBound __cb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getPixelsTypeLowerBound __cb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, 
                                                         java.util.Map<String, String> __ctx, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getPixelsTypeLowerBound(int w, 
                                                         java.util.Map<String, String> __ctx, 
                                                         IceInternal.Functional_DoubleCallback __responseCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                         IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                         IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param __result The asynchronous result object.
     **/
    public double end_getPixelsTypeLowerBound(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     *
     * @param w The channel index.
     **/
    public java.util.List<omero.model.IObject> getCodomainMapContext(int w)
        throws omero.ServerError;

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     *
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.IObject> getCodomainMapContext(int w, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, java.util.Map<String, String> __ctx);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, Ice.Callback __cb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, Callback_RenderingEngine_getCodomainMapContext __cb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, java.util.Map<String, String> __ctx, Callback_RenderingEngine_getCodomainMapContext __cb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, 
                                                       IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, 
                                                       IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param w The channel index.
     * @param __ctx The Context map to send with the invocation.
     * @param __responseCb The lambda response callback.
     * @param __userExceptionCb The lambda user exception callback.
     * @param __exceptionCb The lambda exception callback.
     * @param __sentCb The lambda sent callback.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getCodomainMapContext(int w, 
                                                       java.util.Map<String, String> __ctx, 
                                                       IceInternal.Functional_GenericCallback1<java.util.List<omero.model.IObject>> __responseCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.UserException> __userExceptionCb, 
                                                       IceInternal.Functional_GenericCallback1<Ice.Exception> __exceptionCb, 
                                                       IceInternal.Functional_BoolCallback __sentCb);

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param __result The asynchronous result object.
     **/
    public java.util.List<omero.model.IObject> end_getCodomainMapContext(Ice.AsyncResult __result)
        throws omero.ServerError;
}
